@@ -5,36 +5,10 @@ use blue_engine::{
         uniform_type::Matrix, Engine, ObjectSettings, RotateAxis, ShaderSettings, TextureData,
         Vertex, WindowDescriptor,
     },
-    objects::two_dimensions::{square, triangle},
+    primitive_shapes::{square, triangle},
     utils::default_resources::DEFAULT_MATRIX_4, // text::Text},
 };
-use legion::system;
-
-#[system]
-fn test(#[resource] t: &mut u8) {
-    if *t != u8::MAX {
-        *t += 1;
-        //println!("{}", t);
-    }
-}
-
-/*
-    Good new structure idea:
-
-    Pipeline: Entity with 4 component entity which later on render pass is queried.
-    so e.g. shader is an entity with it's id saved to pipeline. and pipeline is an entity itself.
-
-    OR:
-
-    Pipeline includes all the built data, with the raw saved on the objects. This does have easier use but bigger in runtime size.
-    A good fix for size can be referencing. although that might open to some borrow check errors not allowing same memory borrowed by many...
-
-
-*/
-
-struct haha {
-    data: String,
-}
+use std::time::Duration;
 
 fn main() {
     let mut engine = Engine::new(WindowDescriptor {
@@ -46,29 +20,6 @@ fn main() {
     })
     .expect("win");
 
-    let mut world = legion::World::default();
-
-    let entity = world.push((
-        Vertex {
-            position: [-1f32, -1f32, -1f32],
-            texture: [1f32, 1f32],
-        },
-        0f32,
-    ));
-
-    match world.entry(entity) {
-        Some(data) => {
-            //let t = data.get_component::<f32>();
-            //println!("{:?}", t);
-        }
-        None => {}
-    };
-    let mut scheduler = legion::Schedule::builder()
-        .add_system(test_system())
-        .build();
-    let mut res = legion::Resources::default();
-    res.insert(5u8);
-
     // ===============================
 
     /*let mut font = Text::new(
@@ -120,21 +71,21 @@ fn main() {
     let mut rotation = 0f32;
     let speed = 0.5;
 
-    engine
-        .update_loop(move |renderer, window, objects, events, camera| {
-            scheduler.execute(&mut world, &mut res);
+    /*engine
+    .update_loop(move |renderer, window, objects, events, camera| {
+        scheduler.execute(&mut world, &mut res);
 
-            let camx = start.elapsed().unwrap().as_secs_f32().sin() * radius;
-            let camz = start.elapsed().unwrap().as_secs_f32().cos() * radius;
-            //camera.set_eye([camx, 0.0, camz]);
-            if events.key_pressed(blue_engine::header::KeyboardKeys::S) {
-                let result = camera.position - camera.target * speed;
-                camera.set_position(result.x, result.y, result.z);
-            }
-            if events.key_pressed(blue_engine::header::KeyboardKeys::W) {
-                let result = camera.position + camera.target * speed;
-                camera.set_position(result.x, result.y, result.z);
-            }
-        })
-        .expect("Error during update loop");
+        let camx = start.elapsed().unwrap().as_secs_f32().sin() * radius;
+        let camz = start.elapsed().unwrap().as_secs_f32().cos() * radius;
+        //camera.set_eye([camx, 0.0, camz]);
+        if events.key_pressed(blue_engine::header::KeyboardKeys::S) {
+            let result = camera.position - camera.target * speed;
+            camera.set_position(result.x, result.y, result.z);
+        }
+        if events.key_pressed(blue_engine::header::KeyboardKeys::W) {
+            let result = camera.position + camera.target * speed;
+            camera.set_position(result.x, result.y, result.z);
+        }
+    })
+    .expect("Error during update loop");*/
 }
